﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace RefreshBenchmark
{
    public partial class Form1 : Form
    {

        private LayerOverlay Lines { get { return (LayerOverlay)winformsMap1.Overlays["Lines"]; } }
        private Proj4Projection _proj;
 
        public Form1()
        {
            InitializeComponent();

            winformsMap1.MapUnit = GeographyUnit.Meter;

            LayerOverlay lo = new LayerOverlay();
            lo.Name = "Lines";

            winformsMap1.Overlays.Add("Lines", lo);

            _proj = new Proj4Projection();
            _proj.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(32615);
            _proj.ExternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(32615);
            _proj.Open();
        }

        private void btnBuild_Click(object sender, EventArgs e)
        {

            checkVisible.Checked = true;
            int lineCount = Convert.ToInt32(textLines.Text);

            Lines.Layers.Clear();
            
            for (int i = 0; i < lineCount; i++)
            {
                InMemoryFeatureLayer imfl = new InMemoryFeatureLayer();
                imfl.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColor.StandardColors.Blue, 2),
                new GeoPen(GeoColor.StandardColors.Pink, 2));
                imfl.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                imfl.FeatureSource.Projection = _proj;

                LineShape line = new LineShape();
                line.Vertices.Add(new Vertex(0, i * 250));
                line.Vertices.Add(new Vertex(80000, i * 250));

                Dictionary<string, string> cols = new Dictionary<string, string>();
                cols.Add("LineName", i.ToString());
                cols.Add("Attribute1", "Beezel");
                cols.Add("Attribute2", "Weazel");

                imfl.InternalFeatures.Add(new Feature(line, cols));

                Lines.Layers.Add(i.ToString(), imfl);
            }


            RectangleShape rect = new RectangleShape(0, lineCount * 250, 80000, 0);
            winformsMap1.CurrentExtent = rect;

            Stopwatch s = Stopwatch.StartNew();

            winformsMap1.Refresh(winformsMap1.CurrentExtent, Lines);

            labelRefresh.Text = string.Format("Refresh Time : {0:0.00}s", s.Elapsed.TotalSeconds);
            

        }

        private void checkVisible_CheckedChanged(object sender, EventArgs e)
        {
            Lines.IsVisible = checkVisible.Checked;

            Stopwatch s = Stopwatch.StartNew();

            winformsMap1.Refresh(winformsMap1.CurrentExtent, Lines);

            labelRefresh.Text = string.Format("Refresh Time : {0:0.00}s", s.Elapsed.TotalSeconds);
        }
    }
}
